{{ 
    config(
        materialized='incremental',
        unique_key='tcin'
    )
}}

WITH scores AS (
    SELECT
        tcin,
        ingestion_time,
        material_scores.score AS material_score,
        weight * 0.75 AS weight_score,
        packaging * 0.6 AS packaging_score,
        lookup.score AS origin_score
    FROM {{ source('products', 'products') }} AS products
    LEFT JOIN {{ ref('category_material_scores') }} AS material_scores USING (primary_category)
    LEFT JOIN {{ ref('origin_lookup') }} AS lookup USING (origin)
    {% if is_incremental() %}
        WHERE ingestion_time > (SELECT MAX(ingestion_time) FROM {{ this }})
    {% endif %}
)

SELECT
  tcin,
  ingestion_time,
  material_score,
  weight_score,
  packaging_score,
  origin_score,
  material_score + weight_score + packaging_score + origin_score AS score
FROM scores
